@@ -58,7 +58,7 @@ class Factor(numpy.ndarray):
             try:
                 obj = numpy.array([level_lookup[x] for x in values], dtype=numpy.int32)
             except KeyError:
-                raise ValueError("Missing level value (but existing data point): %s" % x)
+                raise ValueError("Missing level value (but existing data point): %s (levels were %s)" % (x, level_lookup.keys()))
         else:
                 obj = numpy.array(values, dtype=numpy.int32)
 
